"""AbstractAssemblyCompoundDynamicAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import conversion
from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import _6487
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ABSTRACT_ASSEMBLY_COMPOUND_DYNAMIC_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.DynamicAnalyses.Compound",
    "AbstractAssemblyCompoundDynamicAnalysis",
)

if TYPE_CHECKING:
    from mastapy.system_model.analyses_and_results.dynamic_analyses import _6277
    from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
        _6414,
        _6415,
        _6418,
        _6421,
        _6426,
        _6428,
        _6429,
        _6434,
        _6439,
        _6442,
        _6445,
        _6449,
        _6451,
        _6457,
        _6463,
        _6465,
        _6468,
        _6472,
        _6476,
        _6479,
        _6482,
        _6488,
        _6492,
        _6499,
        _6502,
        _6506,
        _6509,
        _6510,
        _6515,
        _6518,
        _6521,
        _6525,
        _6533,
        _6536,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7546, _7543
    from mastapy.system_model.analyses_and_results import _2651


__docformat__ = "restructuredtext en"
__all__ = ("AbstractAssemblyCompoundDynamicAnalysis",)


Self = TypeVar("Self", bound="AbstractAssemblyCompoundDynamicAnalysis")


class AbstractAssemblyCompoundDynamicAnalysis(_6487.PartCompoundDynamicAnalysis):
    """AbstractAssemblyCompoundDynamicAnalysis

    This is a mastapy class.
    """

    TYPE = _ABSTRACT_ASSEMBLY_COMPOUND_DYNAMIC_ANALYSIS
    _CastSelf = TypeVar(
        "_CastSelf", bound="_Cast_AbstractAssemblyCompoundDynamicAnalysis"
    )

    class _Cast_AbstractAssemblyCompoundDynamicAnalysis:
        """Special nested class for casting AbstractAssemblyCompoundDynamicAnalysis to subclasses."""

        def __init__(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
            parent: "AbstractAssemblyCompoundDynamicAnalysis",
        ):
            self._parent = parent

        @property
        def part_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6487.PartCompoundDynamicAnalysis":
            return self._parent._cast(_6487.PartCompoundDynamicAnalysis)

        @property
        def part_compound_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_7546.PartCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7546

            return self._parent._cast(_7546.PartCompoundAnalysis)

        @property
        def design_entity_compound_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_7543.DesignEntityCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7543

            return self._parent._cast(_7543.DesignEntityCompoundAnalysis)

        @property
        def design_entity_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def agma_gleason_conical_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6414.AGMAGleasonConicalGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6414,
            )

            return self._parent._cast(
                _6414.AGMAGleasonConicalGearSetCompoundDynamicAnalysis
            )

        @property
        def assembly_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6415.AssemblyCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6415,
            )

            return self._parent._cast(_6415.AssemblyCompoundDynamicAnalysis)

        @property
        def belt_drive_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6418.BeltDriveCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6418,
            )

            return self._parent._cast(_6418.BeltDriveCompoundDynamicAnalysis)

        @property
        def bevel_differential_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6421.BevelDifferentialGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6421,
            )

            return self._parent._cast(
                _6421.BevelDifferentialGearSetCompoundDynamicAnalysis
            )

        @property
        def bevel_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6426.BevelGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6426,
            )

            return self._parent._cast(_6426.BevelGearSetCompoundDynamicAnalysis)

        @property
        def bolted_joint_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6428.BoltedJointCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6428,
            )

            return self._parent._cast(_6428.BoltedJointCompoundDynamicAnalysis)

        @property
        def clutch_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6429.ClutchCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6429,
            )

            return self._parent._cast(_6429.ClutchCompoundDynamicAnalysis)

        @property
        def concept_coupling_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6434.ConceptCouplingCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6434,
            )

            return self._parent._cast(_6434.ConceptCouplingCompoundDynamicAnalysis)

        @property
        def concept_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6439.ConceptGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6439,
            )

            return self._parent._cast(_6439.ConceptGearSetCompoundDynamicAnalysis)

        @property
        def conical_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6442.ConicalGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6442,
            )

            return self._parent._cast(_6442.ConicalGearSetCompoundDynamicAnalysis)

        @property
        def coupling_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6445.CouplingCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6445,
            )

            return self._parent._cast(_6445.CouplingCompoundDynamicAnalysis)

        @property
        def cvt_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6449.CVTCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6449,
            )

            return self._parent._cast(_6449.CVTCompoundDynamicAnalysis)

        @property
        def cycloidal_assembly_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6451.CycloidalAssemblyCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6451,
            )

            return self._parent._cast(_6451.CycloidalAssemblyCompoundDynamicAnalysis)

        @property
        def cylindrical_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6457.CylindricalGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6457,
            )

            return self._parent._cast(_6457.CylindricalGearSetCompoundDynamicAnalysis)

        @property
        def face_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6463.FaceGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6463,
            )

            return self._parent._cast(_6463.FaceGearSetCompoundDynamicAnalysis)

        @property
        def flexible_pin_assembly_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6465.FlexiblePinAssemblyCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6465,
            )

            return self._parent._cast(_6465.FlexiblePinAssemblyCompoundDynamicAnalysis)

        @property
        def gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6468.GearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6468,
            )

            return self._parent._cast(_6468.GearSetCompoundDynamicAnalysis)

        @property
        def hypoid_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6472.HypoidGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6472,
            )

            return self._parent._cast(_6472.HypoidGearSetCompoundDynamicAnalysis)

        @property
        def klingelnberg_cyclo_palloid_conical_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6476.KlingelnbergCycloPalloidConicalGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6476,
            )

            return self._parent._cast(
                _6476.KlingelnbergCycloPalloidConicalGearSetCompoundDynamicAnalysis
            )

        @property
        def klingelnberg_cyclo_palloid_hypoid_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6479.KlingelnbergCycloPalloidHypoidGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6479,
            )

            return self._parent._cast(
                _6479.KlingelnbergCycloPalloidHypoidGearSetCompoundDynamicAnalysis
            )

        @property
        def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6482.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6482,
            )

            return self._parent._cast(
                _6482.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundDynamicAnalysis
            )

        @property
        def part_to_part_shear_coupling_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6488.PartToPartShearCouplingCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6488,
            )

            return self._parent._cast(
                _6488.PartToPartShearCouplingCompoundDynamicAnalysis
            )

        @property
        def planetary_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6492.PlanetaryGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6492,
            )

            return self._parent._cast(_6492.PlanetaryGearSetCompoundDynamicAnalysis)

        @property
        def rolling_ring_assembly_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6499.RollingRingAssemblyCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6499,
            )

            return self._parent._cast(_6499.RollingRingAssemblyCompoundDynamicAnalysis)

        @property
        def root_assembly_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6502.RootAssemblyCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6502,
            )

            return self._parent._cast(_6502.RootAssemblyCompoundDynamicAnalysis)

        @property
        def specialised_assembly_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6506.SpecialisedAssemblyCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6506,
            )

            return self._parent._cast(_6506.SpecialisedAssemblyCompoundDynamicAnalysis)

        @property
        def spiral_bevel_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6509.SpiralBevelGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6509,
            )

            return self._parent._cast(_6509.SpiralBevelGearSetCompoundDynamicAnalysis)

        @property
        def spring_damper_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6510.SpringDamperCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6510,
            )

            return self._parent._cast(_6510.SpringDamperCompoundDynamicAnalysis)

        @property
        def straight_bevel_diff_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6515.StraightBevelDiffGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6515,
            )

            return self._parent._cast(
                _6515.StraightBevelDiffGearSetCompoundDynamicAnalysis
            )

        @property
        def straight_bevel_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6518.StraightBevelGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6518,
            )

            return self._parent._cast(_6518.StraightBevelGearSetCompoundDynamicAnalysis)

        @property
        def synchroniser_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6521.SynchroniserCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6521,
            )

            return self._parent._cast(_6521.SynchroniserCompoundDynamicAnalysis)

        @property
        def torque_converter_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6525.TorqueConverterCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6525,
            )

            return self._parent._cast(_6525.TorqueConverterCompoundDynamicAnalysis)

        @property
        def worm_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6533.WormGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6533,
            )

            return self._parent._cast(_6533.WormGearSetCompoundDynamicAnalysis)

        @property
        def zerol_bevel_gear_set_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "_6536.ZerolBevelGearSetCompoundDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import (
                _6536,
            )

            return self._parent._cast(_6536.ZerolBevelGearSetCompoundDynamicAnalysis)

        @property
        def abstract_assembly_compound_dynamic_analysis(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
        ) -> "AbstractAssemblyCompoundDynamicAnalysis":
            return self._parent

        def __getattr__(
            self: "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self, instance_to_wrap: "AbstractAssemblyCompoundDynamicAnalysis.TYPE"
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_analysis_cases(
        self: Self,
    ) -> "List[_6277.AbstractAssemblyDynamicAnalysis]":
        """List[mastapy.system_model.analyses_and_results.dynamic_analyses.AbstractAssemblyDynamicAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def assembly_analysis_cases_ready(
        self: Self,
    ) -> "List[_6277.AbstractAssemblyDynamicAnalysis]":
        """List[mastapy.system_model.analyses_and_results.dynamic_analyses.AbstractAssemblyDynamicAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: Self,
    ) -> "AbstractAssemblyCompoundDynamicAnalysis._Cast_AbstractAssemblyCompoundDynamicAnalysis":
        return self._Cast_AbstractAssemblyCompoundDynamicAnalysis(self)



"""CVTBeltConnectionCompoundCriticalSpeedAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import conversion
from mastapy.system_model.analyses_and_results.critical_speed_analyses.compound import (
    _6684,
)
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_CVT_BELT_CONNECTION_COMPOUND_CRITICAL_SPEED_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.CriticalSpeedAnalyses.Compound",
    "CVTBeltConnectionCompoundCriticalSpeedAnalysis",
)

if TYPE_CHECKING:
    from mastapy.system_model.analyses_and_results.critical_speed_analyses import _6586
    from mastapy.system_model.analyses_and_results.critical_speed_analyses.compound import (
        _6740,
        _6710,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7539, _7543
    from mastapy.system_model.analyses_and_results import _2651


__docformat__ = "restructuredtext en"
__all__ = ("CVTBeltConnectionCompoundCriticalSpeedAnalysis",)


Self = TypeVar("Self", bound="CVTBeltConnectionCompoundCriticalSpeedAnalysis")


class CVTBeltConnectionCompoundCriticalSpeedAnalysis(
    _6684.BeltConnectionCompoundCriticalSpeedAnalysis
):
    """CVTBeltConnectionCompoundCriticalSpeedAnalysis

    This is a mastapy class.
    """

    TYPE = _CVT_BELT_CONNECTION_COMPOUND_CRITICAL_SPEED_ANALYSIS
    _CastSelf = TypeVar(
        "_CastSelf", bound="_Cast_CVTBeltConnectionCompoundCriticalSpeedAnalysis"
    )

    class _Cast_CVTBeltConnectionCompoundCriticalSpeedAnalysis:
        """Special nested class for casting CVTBeltConnectionCompoundCriticalSpeedAnalysis to subclasses."""

        def __init__(
            self: "CVTBeltConnectionCompoundCriticalSpeedAnalysis._Cast_CVTBeltConnectionCompoundCriticalSpeedAnalysis",
            parent: "CVTBeltConnectionCompoundCriticalSpeedAnalysis",
        ):
            self._parent = parent

        @property
        def belt_connection_compound_critical_speed_analysis(
            self: "CVTBeltConnectionCompoundCriticalSpeedAnalysis._Cast_CVTBeltConnectionCompoundCriticalSpeedAnalysis",
        ) -> "_6684.BeltConnectionCompoundCriticalSpeedAnalysis":
            return self._parent._cast(_6684.BeltConnectionCompoundCriticalSpeedAnalysis)

        @property
        def inter_mountable_component_connection_compound_critical_speed_analysis(
            self: "CVTBeltConnectionCompoundCriticalSpeedAnalysis._Cast_CVTBeltConnectionCompoundCriticalSpeedAnalysis",
        ) -> "_6740.InterMountableComponentConnectionCompoundCriticalSpeedAnalysis":
            from mastapy.system_model.analyses_and_results.critical_speed_analyses.compound import (
                _6740,
            )

            return self._parent._cast(
                _6740.InterMountableComponentConnectionCompoundCriticalSpeedAnalysis
            )

        @property
        def connection_compound_critical_speed_analysis(
            self: "CVTBeltConnectionCompoundCriticalSpeedAnalysis._Cast_CVTBeltConnectionCompoundCriticalSpeedAnalysis",
        ) -> "_6710.ConnectionCompoundCriticalSpeedAnalysis":
            from mastapy.system_model.analyses_and_results.critical_speed_analyses.compound import (
                _6710,
            )

            return self._parent._cast(_6710.ConnectionCompoundCriticalSpeedAnalysis)

        @property
        def connection_compound_analysis(
            self: "CVTBeltConnectionCompoundCriticalSpeedAnalysis._Cast_CVTBeltConnectionCompoundCriticalSpeedAnalysis",
        ) -> "_7539.ConnectionCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7539

            return self._parent._cast(_7539.ConnectionCompoundAnalysis)

        @property
        def design_entity_compound_analysis(
            self: "CVTBeltConnectionCompoundCriticalSpeedAnalysis._Cast_CVTBeltConnectionCompoundCriticalSpeedAnalysis",
        ) -> "_7543.DesignEntityCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7543

            return self._parent._cast(_7543.DesignEntityCompoundAnalysis)

        @property
        def design_entity_analysis(
            self: "CVTBeltConnectionCompoundCriticalSpeedAnalysis._Cast_CVTBeltConnectionCompoundCriticalSpeedAnalysis",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def cvt_belt_connection_compound_critical_speed_analysis(
            self: "CVTBeltConnectionCompoundCriticalSpeedAnalysis._Cast_CVTBeltConnectionCompoundCriticalSpeedAnalysis",
        ) -> "CVTBeltConnectionCompoundCriticalSpeedAnalysis":
            return self._parent

        def __getattr__(
            self: "CVTBeltConnectionCompoundCriticalSpeedAnalysis._Cast_CVTBeltConnectionCompoundCriticalSpeedAnalysis",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self,
        instance_to_wrap: "CVTBeltConnectionCompoundCriticalSpeedAnalysis.TYPE",
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_analysis_cases_ready(
        self: Self,
    ) -> "List[_6586.CVTBeltConnectionCriticalSpeedAnalysis]":
        """List[mastapy.system_model.analyses_and_results.critical_speed_analyses.CVTBeltConnectionCriticalSpeedAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def connection_analysis_cases(
        self: Self,
    ) -> "List[_6586.CVTBeltConnectionCriticalSpeedAnalysis]":
        """List[mastapy.system_model.analyses_and_results.critical_speed_analyses.CVTBeltConnectionCriticalSpeedAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: Self,
    ) -> "CVTBeltConnectionCompoundCriticalSpeedAnalysis._Cast_CVTBeltConnectionCompoundCriticalSpeedAnalysis":
        return self._Cast_CVTBeltConnectionCompoundCriticalSpeedAnalysis(self)



"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._501 import CylindricalGearSetRatingOptimisationHelper
    from ._502 import OptimisationResultsPair
    from ._503 import SafetyFactorOptimisationResults
    from ._504 import SafetyFactorOptimisationStepResult
    from ._505 import SafetyFactorOptimisationStepResultAngle
    from ._506 import SafetyFactorOptimisationStepResultNumber
    from ._507 import SafetyFactorOptimisationStepResultShortLength
else:
    import_structure = {
        "_501": ["CylindricalGearSetRatingOptimisationHelper"],
        "_502": ["OptimisationResultsPair"],
        "_503": ["SafetyFactorOptimisationResults"],
        "_504": ["SafetyFactorOptimisationStepResult"],
        "_505": ["SafetyFactorOptimisationStepResultAngle"],
        "_506": ["SafetyFactorOptimisationStepResultNumber"],
        "_507": ["SafetyFactorOptimisationStepResultShortLength"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "CylindricalGearSetRatingOptimisationHelper",
    "OptimisationResultsPair",
    "SafetyFactorOptimisationResults",
    "SafetyFactorOptimisationStepResult",
    "SafetyFactorOptimisationStepResultAngle",
    "SafetyFactorOptimisationStepResultNumber",
    "SafetyFactorOptimisationStepResultShortLength",
)



"""BevelDifferentialSunGearAdvancedSystemDeflection"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.advanced_system_deflections import _7284
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_BEVEL_DIFFERENTIAL_SUN_GEAR_ADVANCED_SYSTEM_DEFLECTION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections",
    "BevelDifferentialSunGearAdvancedSystemDeflection",
)

if TYPE_CHECKING:
    from mastapy.system_model.part_model.gears import _2518
    from mastapy.system_model.analyses_and_results.advanced_system_deflections import (
        _7289,
        _7277,
        _7305,
        _7333,
        _7353,
        _7298,
        _7355,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7548, _7545
    from mastapy.system_model.analyses_and_results import _2657, _2653, _2651


__docformat__ = "restructuredtext en"
__all__ = ("BevelDifferentialSunGearAdvancedSystemDeflection",)


Self = TypeVar("Self", bound="BevelDifferentialSunGearAdvancedSystemDeflection")


class BevelDifferentialSunGearAdvancedSystemDeflection(
    _7284.BevelDifferentialGearAdvancedSystemDeflection
):
    """BevelDifferentialSunGearAdvancedSystemDeflection

    This is a mastapy class.
    """

    TYPE = _BEVEL_DIFFERENTIAL_SUN_GEAR_ADVANCED_SYSTEM_DEFLECTION
    _CastSelf = TypeVar(
        "_CastSelf", bound="_Cast_BevelDifferentialSunGearAdvancedSystemDeflection"
    )

    class _Cast_BevelDifferentialSunGearAdvancedSystemDeflection:
        """Special nested class for casting BevelDifferentialSunGearAdvancedSystemDeflection to subclasses."""

        def __init__(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
            parent: "BevelDifferentialSunGearAdvancedSystemDeflection",
        ):
            self._parent = parent

        @property
        def bevel_differential_gear_advanced_system_deflection(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
        ) -> "_7284.BevelDifferentialGearAdvancedSystemDeflection":
            return self._parent._cast(
                _7284.BevelDifferentialGearAdvancedSystemDeflection
            )

        @property
        def bevel_gear_advanced_system_deflection(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
        ) -> "_7289.BevelGearAdvancedSystemDeflection":
            from mastapy.system_model.analyses_and_results.advanced_system_deflections import (
                _7289,
            )

            return self._parent._cast(_7289.BevelGearAdvancedSystemDeflection)

        @property
        def agma_gleason_conical_gear_advanced_system_deflection(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
        ) -> "_7277.AGMAGleasonConicalGearAdvancedSystemDeflection":
            from mastapy.system_model.analyses_and_results.advanced_system_deflections import (
                _7277,
            )

            return self._parent._cast(
                _7277.AGMAGleasonConicalGearAdvancedSystemDeflection
            )

        @property
        def conical_gear_advanced_system_deflection(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
        ) -> "_7305.ConicalGearAdvancedSystemDeflection":
            from mastapy.system_model.analyses_and_results.advanced_system_deflections import (
                _7305,
            )

            return self._parent._cast(_7305.ConicalGearAdvancedSystemDeflection)

        @property
        def gear_advanced_system_deflection(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
        ) -> "_7333.GearAdvancedSystemDeflection":
            from mastapy.system_model.analyses_and_results.advanced_system_deflections import (
                _7333,
            )

            return self._parent._cast(_7333.GearAdvancedSystemDeflection)

        @property
        def mountable_component_advanced_system_deflection(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
        ) -> "_7353.MountableComponentAdvancedSystemDeflection":
            from mastapy.system_model.analyses_and_results.advanced_system_deflections import (
                _7353,
            )

            return self._parent._cast(_7353.MountableComponentAdvancedSystemDeflection)

        @property
        def component_advanced_system_deflection(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
        ) -> "_7298.ComponentAdvancedSystemDeflection":
            from mastapy.system_model.analyses_and_results.advanced_system_deflections import (
                _7298,
            )

            return self._parent._cast(_7298.ComponentAdvancedSystemDeflection)

        @property
        def part_advanced_system_deflection(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
        ) -> "_7355.PartAdvancedSystemDeflection":
            from mastapy.system_model.analyses_and_results.advanced_system_deflections import (
                _7355,
            )

            return self._parent._cast(_7355.PartAdvancedSystemDeflection)

        @property
        def part_static_load_analysis_case(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
        ) -> "_7548.PartStaticLoadAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7548

            return self._parent._cast(_7548.PartStaticLoadAnalysisCase)

        @property
        def part_analysis_case(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
        ) -> "_7545.PartAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7545

            return self._parent._cast(_7545.PartAnalysisCase)

        @property
        def part_analysis(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
        ) -> "_2657.PartAnalysis":
            from mastapy.system_model.analyses_and_results import _2657

            return self._parent._cast(_2657.PartAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
        ) -> "_2653.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2653

            return self._parent._cast(_2653.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def bevel_differential_sun_gear_advanced_system_deflection(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
        ) -> "BevelDifferentialSunGearAdvancedSystemDeflection":
            return self._parent

        def __getattr__(
            self: "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self,
        instance_to_wrap: "BevelDifferentialSunGearAdvancedSystemDeflection.TYPE",
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self: Self) -> "_2518.BevelDifferentialSunGear":
        """mastapy.system_model.part_model.gears.BevelDifferentialSunGear

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "BevelDifferentialSunGearAdvancedSystemDeflection._Cast_BevelDifferentialSunGearAdvancedSystemDeflection":
        return self._Cast_BevelDifferentialSunGearAdvancedSystemDeflection(self)



"""TorqueConverterConnectionMultibodyDynamicsAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.mbd_analyses import _5416
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_TORQUE_CONVERTER_CONNECTION_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses",
    "TorqueConverterConnectionMultibodyDynamicsAnalysis",
)

if TYPE_CHECKING:
    from mastapy.system_model.analyses_and_results.mbd_analyses import (
        _5512,
        _5449,
        _5414,
    )
    from mastapy.system_model.connections_and_sockets.couplings import _2352
    from mastapy.system_model.analyses_and_results.static_loads import _6973
    from mastapy.system_model.analyses_and_results.analysis_cases import _7542, _7538
    from mastapy.system_model.analyses_and_results import _2649, _2653, _2651


__docformat__ = "restructuredtext en"
__all__ = ("TorqueConverterConnectionMultibodyDynamicsAnalysis",)


Self = TypeVar("Self", bound="TorqueConverterConnectionMultibodyDynamicsAnalysis")


class TorqueConverterConnectionMultibodyDynamicsAnalysis(
    _5416.CouplingConnectionMultibodyDynamicsAnalysis
):
    """TorqueConverterConnectionMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE = _TORQUE_CONVERTER_CONNECTION_MULTIBODY_DYNAMICS_ANALYSIS
    _CastSelf = TypeVar(
        "_CastSelf", bound="_Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis"
    )

    class _Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis:
        """Special nested class for casting TorqueConverterConnectionMultibodyDynamicsAnalysis to subclasses."""

        def __init__(
            self: "TorqueConverterConnectionMultibodyDynamicsAnalysis._Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis",
            parent: "TorqueConverterConnectionMultibodyDynamicsAnalysis",
        ):
            self._parent = parent

        @property
        def coupling_connection_multibody_dynamics_analysis(
            self: "TorqueConverterConnectionMultibodyDynamicsAnalysis._Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis",
        ) -> "_5416.CouplingConnectionMultibodyDynamicsAnalysis":
            return self._parent._cast(_5416.CouplingConnectionMultibodyDynamicsAnalysis)

        @property
        def inter_mountable_component_connection_multibody_dynamics_analysis(
            self: "TorqueConverterConnectionMultibodyDynamicsAnalysis._Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis",
        ) -> "_5449.InterMountableComponentConnectionMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5449

            return self._parent._cast(
                _5449.InterMountableComponentConnectionMultibodyDynamicsAnalysis
            )

        @property
        def connection_multibody_dynamics_analysis(
            self: "TorqueConverterConnectionMultibodyDynamicsAnalysis._Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis",
        ) -> "_5414.ConnectionMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5414

            return self._parent._cast(_5414.ConnectionMultibodyDynamicsAnalysis)

        @property
        def connection_time_series_load_analysis_case(
            self: "TorqueConverterConnectionMultibodyDynamicsAnalysis._Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis",
        ) -> "_7542.ConnectionTimeSeriesLoadAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7542

            return self._parent._cast(_7542.ConnectionTimeSeriesLoadAnalysisCase)

        @property
        def connection_analysis_case(
            self: "TorqueConverterConnectionMultibodyDynamicsAnalysis._Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis",
        ) -> "_7538.ConnectionAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7538

            return self._parent._cast(_7538.ConnectionAnalysisCase)

        @property
        def connection_analysis(
            self: "TorqueConverterConnectionMultibodyDynamicsAnalysis._Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis",
        ) -> "_2649.ConnectionAnalysis":
            from mastapy.system_model.analyses_and_results import _2649

            return self._parent._cast(_2649.ConnectionAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "TorqueConverterConnectionMultibodyDynamicsAnalysis._Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis",
        ) -> "_2653.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2653

            return self._parent._cast(_2653.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "TorqueConverterConnectionMultibodyDynamicsAnalysis._Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def torque_converter_connection_multibody_dynamics_analysis(
            self: "TorqueConverterConnectionMultibodyDynamicsAnalysis._Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis",
        ) -> "TorqueConverterConnectionMultibodyDynamicsAnalysis":
            return self._parent

        def __getattr__(
            self: "TorqueConverterConnectionMultibodyDynamicsAnalysis._Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self,
        instance_to_wrap: "TorqueConverterConnectionMultibodyDynamicsAnalysis.TYPE",
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def capacity_factor_k(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CapacityFactorK

        if temp is None:
            return 0.0

        return temp

    @property
    def inverse_capacity_factor_1k(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.InverseCapacityFactor1K

        if temp is None:
            return 0.0

        return temp

    @property
    def is_locked(self: Self) -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = self.wrapped.IsLocked

        if temp is None:
            return False

        return temp

    @property
    def lock_up_clutch_temperature(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LockUpClutchTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def lock_up_viscous_torque(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LockUpViscousTorque

        if temp is None:
            return 0.0

        return temp

    @property
    def locked_torque(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LockedTorque

        if temp is None:
            return 0.0

        return temp

    @property
    def locking_status(self: Self) -> "_5512.TorqueConverterStatus":
        """mastapy.system_model.analyses_and_results.mbd_analyses.TorqueConverterStatus

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LockingStatus

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.TorqueConverterStatus",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.system_model.analyses_and_results.mbd_analyses._5512",
            "TorqueConverterStatus",
        )(value)

    @property
    def percentage_applied_pressure(self: Self) -> "float":
        """float"""
        temp = self.wrapped.PercentageAppliedPressure

        if temp is None:
            return 0.0

        return temp

    @percentage_applied_pressure.setter
    @enforce_parameter_types
    def percentage_applied_pressure(self: Self, value: "float"):
        self.wrapped.PercentageAppliedPressure = (
            float(value) if value is not None else 0.0
        )

    @property
    def power_loss(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PowerLoss

        if temp is None:
            return 0.0

        return temp

    @property
    def pump_torque(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PumpTorque

        if temp is None:
            return 0.0

        return temp

    @property
    def speed_ratio(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SpeedRatio

        if temp is None:
            return 0.0

        return temp

    @property
    def torque_ratio(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TorqueRatio

        if temp is None:
            return 0.0

        return temp

    @property
    def turbine_torque(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TurbineTorque

        if temp is None:
            return 0.0

        return temp

    @property
    def connection_design(self: Self) -> "_2352.TorqueConverterConnection":
        """mastapy.system_model.connections_and_sockets.couplings.TorqueConverterConnection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def connection_load_case(self: Self) -> "_6973.TorqueConverterConnectionLoadCase":
        """mastapy.system_model.analyses_and_results.static_loads.TorqueConverterConnectionLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionLoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "TorqueConverterConnectionMultibodyDynamicsAnalysis._Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis":
        return self._Cast_TorqueConverterConnectionMultibodyDynamicsAnalysis(self)



"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._3116 import AbstractAssemblyCompoundSteadyStateSynchronousResponse
    from ._3117 import AbstractShaftCompoundSteadyStateSynchronousResponse
    from ._3118 import AbstractShaftOrHousingCompoundSteadyStateSynchronousResponse
    from ._3119 import (
        AbstractShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse,
    )
    from ._3120 import AGMAGleasonConicalGearCompoundSteadyStateSynchronousResponse
    from ._3121 import AGMAGleasonConicalGearMeshCompoundSteadyStateSynchronousResponse
    from ._3122 import AGMAGleasonConicalGearSetCompoundSteadyStateSynchronousResponse
    from ._3123 import AssemblyCompoundSteadyStateSynchronousResponse
    from ._3124 import BearingCompoundSteadyStateSynchronousResponse
    from ._3125 import BeltConnectionCompoundSteadyStateSynchronousResponse
    from ._3126 import BeltDriveCompoundSteadyStateSynchronousResponse
    from ._3127 import BevelDifferentialGearCompoundSteadyStateSynchronousResponse
    from ._3128 import BevelDifferentialGearMeshCompoundSteadyStateSynchronousResponse
    from ._3129 import BevelDifferentialGearSetCompoundSteadyStateSynchronousResponse
    from ._3130 import BevelDifferentialPlanetGearCompoundSteadyStateSynchronousResponse
    from ._3131 import BevelDifferentialSunGearCompoundSteadyStateSynchronousResponse
    from ._3132 import BevelGearCompoundSteadyStateSynchronousResponse
    from ._3133 import BevelGearMeshCompoundSteadyStateSynchronousResponse
    from ._3134 import BevelGearSetCompoundSteadyStateSynchronousResponse
    from ._3135 import BoltCompoundSteadyStateSynchronousResponse
    from ._3136 import BoltedJointCompoundSteadyStateSynchronousResponse
    from ._3137 import ClutchCompoundSteadyStateSynchronousResponse
    from ._3138 import ClutchConnectionCompoundSteadyStateSynchronousResponse
    from ._3139 import ClutchHalfCompoundSteadyStateSynchronousResponse
    from ._3140 import CoaxialConnectionCompoundSteadyStateSynchronousResponse
    from ._3141 import ComponentCompoundSteadyStateSynchronousResponse
    from ._3142 import ConceptCouplingCompoundSteadyStateSynchronousResponse
    from ._3143 import ConceptCouplingConnectionCompoundSteadyStateSynchronousResponse
    from ._3144 import ConceptCouplingHalfCompoundSteadyStateSynchronousResponse
    from ._3145 import ConceptGearCompoundSteadyStateSynchronousResponse
    from ._3146 import ConceptGearMeshCompoundSteadyStateSynchronousResponse
    from ._3147 import ConceptGearSetCompoundSteadyStateSynchronousResponse
    from ._3148 import ConicalGearCompoundSteadyStateSynchronousResponse
    from ._3149 import ConicalGearMeshCompoundSteadyStateSynchronousResponse
    from ._3150 import ConicalGearSetCompoundSteadyStateSynchronousResponse
    from ._3151 import ConnectionCompoundSteadyStateSynchronousResponse
    from ._3152 import ConnectorCompoundSteadyStateSynchronousResponse
    from ._3153 import CouplingCompoundSteadyStateSynchronousResponse
    from ._3154 import CouplingConnectionCompoundSteadyStateSynchronousResponse
    from ._3155 import CouplingHalfCompoundSteadyStateSynchronousResponse
    from ._3156 import CVTBeltConnectionCompoundSteadyStateSynchronousResponse
    from ._3157 import CVTCompoundSteadyStateSynchronousResponse
    from ._3158 import CVTPulleyCompoundSteadyStateSynchronousResponse
    from ._3159 import CycloidalAssemblyCompoundSteadyStateSynchronousResponse
    from ._3160 import (
        CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from ._3161 import CycloidalDiscCompoundSteadyStateSynchronousResponse
    from ._3162 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from ._3163 import CylindricalGearCompoundSteadyStateSynchronousResponse
    from ._3164 import CylindricalGearMeshCompoundSteadyStateSynchronousResponse
    from ._3165 import CylindricalGearSetCompoundSteadyStateSynchronousResponse
    from ._3166 import CylindricalPlanetGearCompoundSteadyStateSynchronousResponse
    from ._3167 import DatumCompoundSteadyStateSynchronousResponse
    from ._3168 import ExternalCADModelCompoundSteadyStateSynchronousResponse
    from ._3169 import FaceGearCompoundSteadyStateSynchronousResponse
    from ._3170 import FaceGearMeshCompoundSteadyStateSynchronousResponse
    from ._3171 import FaceGearSetCompoundSteadyStateSynchronousResponse
    from ._3172 import FEPartCompoundSteadyStateSynchronousResponse
    from ._3173 import FlexiblePinAssemblyCompoundSteadyStateSynchronousResponse
    from ._3174 import GearCompoundSteadyStateSynchronousResponse
    from ._3175 import GearMeshCompoundSteadyStateSynchronousResponse
    from ._3176 import GearSetCompoundSteadyStateSynchronousResponse
    from ._3177 import GuideDxfModelCompoundSteadyStateSynchronousResponse
    from ._3178 import HypoidGearCompoundSteadyStateSynchronousResponse
    from ._3179 import HypoidGearMeshCompoundSteadyStateSynchronousResponse
    from ._3180 import HypoidGearSetCompoundSteadyStateSynchronousResponse
    from ._3181 import (
        InterMountableComponentConnectionCompoundSteadyStateSynchronousResponse,
    )
    from ._3182 import (
        KlingelnbergCycloPalloidConicalGearCompoundSteadyStateSynchronousResponse,
    )
    from ._3183 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from ._3184 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundSteadyStateSynchronousResponse,
    )
    from ._3185 import (
        KlingelnbergCycloPalloidHypoidGearCompoundSteadyStateSynchronousResponse,
    )
    from ._3186 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from ._3187 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundSteadyStateSynchronousResponse,
    )
    from ._3188 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundSteadyStateSynchronousResponse,
    )
    from ._3189 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from ._3190 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponse,
    )
    from ._3191 import MassDiscCompoundSteadyStateSynchronousResponse
    from ._3192 import MeasurementComponentCompoundSteadyStateSynchronousResponse
    from ._3193 import MountableComponentCompoundSteadyStateSynchronousResponse
    from ._3194 import OilSealCompoundSteadyStateSynchronousResponse
    from ._3195 import PartCompoundSteadyStateSynchronousResponse
    from ._3196 import PartToPartShearCouplingCompoundSteadyStateSynchronousResponse
    from ._3197 import (
        PartToPartShearCouplingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from ._3198 import PartToPartShearCouplingHalfCompoundSteadyStateSynchronousResponse
    from ._3199 import PlanetaryConnectionCompoundSteadyStateSynchronousResponse
    from ._3200 import PlanetaryGearSetCompoundSteadyStateSynchronousResponse
    from ._3201 import PlanetCarrierCompoundSteadyStateSynchronousResponse
    from ._3202 import PointLoadCompoundSteadyStateSynchronousResponse
    from ._3203 import PowerLoadCompoundSteadyStateSynchronousResponse
    from ._3204 import PulleyCompoundSteadyStateSynchronousResponse
    from ._3205 import RingPinsCompoundSteadyStateSynchronousResponse
    from ._3206 import RingPinsToDiscConnectionCompoundSteadyStateSynchronousResponse
    from ._3207 import RollingRingAssemblyCompoundSteadyStateSynchronousResponse
    from ._3208 import RollingRingCompoundSteadyStateSynchronousResponse
    from ._3209 import RollingRingConnectionCompoundSteadyStateSynchronousResponse
    from ._3210 import RootAssemblyCompoundSteadyStateSynchronousResponse
    from ._3211 import ShaftCompoundSteadyStateSynchronousResponse
    from ._3212 import ShaftHubConnectionCompoundSteadyStateSynchronousResponse
    from ._3213 import (
        ShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse,
    )
    from ._3214 import SpecialisedAssemblyCompoundSteadyStateSynchronousResponse
    from ._3215 import SpiralBevelGearCompoundSteadyStateSynchronousResponse
    from ._3216 import SpiralBevelGearMeshCompoundSteadyStateSynchronousResponse
    from ._3217 import SpiralBevelGearSetCompoundSteadyStateSynchronousResponse
    from ._3218 import SpringDamperCompoundSteadyStateSynchronousResponse
    from ._3219 import SpringDamperConnectionCompoundSteadyStateSynchronousResponse
    from ._3220 import SpringDamperHalfCompoundSteadyStateSynchronousResponse
    from ._3221 import StraightBevelDiffGearCompoundSteadyStateSynchronousResponse
    from ._3222 import StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponse
    from ._3223 import StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponse
    from ._3224 import StraightBevelGearCompoundSteadyStateSynchronousResponse
    from ._3225 import StraightBevelGearMeshCompoundSteadyStateSynchronousResponse
    from ._3226 import StraightBevelGearSetCompoundSteadyStateSynchronousResponse
    from ._3227 import StraightBevelPlanetGearCompoundSteadyStateSynchronousResponse
    from ._3228 import StraightBevelSunGearCompoundSteadyStateSynchronousResponse
    from ._3229 import SynchroniserCompoundSteadyStateSynchronousResponse
    from ._3230 import SynchroniserHalfCompoundSteadyStateSynchronousResponse
    from ._3231 import SynchroniserPartCompoundSteadyStateSynchronousResponse
    from ._3232 import SynchroniserSleeveCompoundSteadyStateSynchronousResponse
    from ._3233 import TorqueConverterCompoundSteadyStateSynchronousResponse
    from ._3234 import TorqueConverterConnectionCompoundSteadyStateSynchronousResponse
    from ._3235 import TorqueConverterPumpCompoundSteadyStateSynchronousResponse
    from ._3236 import TorqueConverterTurbineCompoundSteadyStateSynchronousResponse
    from ._3237 import UnbalancedMassCompoundSteadyStateSynchronousResponse
    from ._3238 import VirtualComponentCompoundSteadyStateSynchronousResponse
    from ._3239 import WormGearCompoundSteadyStateSynchronousResponse
    from ._3240 import WormGearMeshCompoundSteadyStateSynchronousResponse
    from ._3241 import WormGearSetCompoundSteadyStateSynchronousResponse
    from ._3242 import ZerolBevelGearCompoundSteadyStateSynchronousResponse
    from ._3243 import ZerolBevelGearMeshCompoundSteadyStateSynchronousResponse
    from ._3244 import ZerolBevelGearSetCompoundSteadyStateSynchronousResponse
else:
    import_structure = {
        "_3116": ["AbstractAssemblyCompoundSteadyStateSynchronousResponse"],
        "_3117": ["AbstractShaftCompoundSteadyStateSynchronousResponse"],
        "_3118": ["AbstractShaftOrHousingCompoundSteadyStateSynchronousResponse"],
        "_3119": [
            "AbstractShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_3120": ["AGMAGleasonConicalGearCompoundSteadyStateSynchronousResponse"],
        "_3121": ["AGMAGleasonConicalGearMeshCompoundSteadyStateSynchronousResponse"],
        "_3122": ["AGMAGleasonConicalGearSetCompoundSteadyStateSynchronousResponse"],
        "_3123": ["AssemblyCompoundSteadyStateSynchronousResponse"],
        "_3124": ["BearingCompoundSteadyStateSynchronousResponse"],
        "_3125": ["BeltConnectionCompoundSteadyStateSynchronousResponse"],
        "_3126": ["BeltDriveCompoundSteadyStateSynchronousResponse"],
        "_3127": ["BevelDifferentialGearCompoundSteadyStateSynchronousResponse"],
        "_3128": ["BevelDifferentialGearMeshCompoundSteadyStateSynchronousResponse"],
        "_3129": ["BevelDifferentialGearSetCompoundSteadyStateSynchronousResponse"],
        "_3130": ["BevelDifferentialPlanetGearCompoundSteadyStateSynchronousResponse"],
        "_3131": ["BevelDifferentialSunGearCompoundSteadyStateSynchronousResponse"],
        "_3132": ["BevelGearCompoundSteadyStateSynchronousResponse"],
        "_3133": ["BevelGearMeshCompoundSteadyStateSynchronousResponse"],
        "_3134": ["BevelGearSetCompoundSteadyStateSynchronousResponse"],
        "_3135": ["BoltCompoundSteadyStateSynchronousResponse"],
        "_3136": ["BoltedJointCompoundSteadyStateSynchronousResponse"],
        "_3137": ["ClutchCompoundSteadyStateSynchronousResponse"],
        "_3138": ["ClutchConnectionCompoundSteadyStateSynchronousResponse"],
        "_3139": ["ClutchHalfCompoundSteadyStateSynchronousResponse"],
        "_3140": ["CoaxialConnectionCompoundSteadyStateSynchronousResponse"],
        "_3141": ["ComponentCompoundSteadyStateSynchronousResponse"],
        "_3142": ["ConceptCouplingCompoundSteadyStateSynchronousResponse"],
        "_3143": ["ConceptCouplingConnectionCompoundSteadyStateSynchronousResponse"],
        "_3144": ["ConceptCouplingHalfCompoundSteadyStateSynchronousResponse"],
        "_3145": ["ConceptGearCompoundSteadyStateSynchronousResponse"],
        "_3146": ["ConceptGearMeshCompoundSteadyStateSynchronousResponse"],
        "_3147": ["ConceptGearSetCompoundSteadyStateSynchronousResponse"],
        "_3148": ["ConicalGearCompoundSteadyStateSynchronousResponse"],
        "_3149": ["ConicalGearMeshCompoundSteadyStateSynchronousResponse"],
        "_3150": ["ConicalGearSetCompoundSteadyStateSynchronousResponse"],
        "_3151": ["ConnectionCompoundSteadyStateSynchronousResponse"],
        "_3152": ["ConnectorCompoundSteadyStateSynchronousResponse"],
        "_3153": ["CouplingCompoundSteadyStateSynchronousResponse"],
        "_3154": ["CouplingConnectionCompoundSteadyStateSynchronousResponse"],
        "_3155": ["CouplingHalfCompoundSteadyStateSynchronousResponse"],
        "_3156": ["CVTBeltConnectionCompoundSteadyStateSynchronousResponse"],
        "_3157": ["CVTCompoundSteadyStateSynchronousResponse"],
        "_3158": ["CVTPulleyCompoundSteadyStateSynchronousResponse"],
        "_3159": ["CycloidalAssemblyCompoundSteadyStateSynchronousResponse"],
        "_3160": [
            "CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_3161": ["CycloidalDiscCompoundSteadyStateSynchronousResponse"],
        "_3162": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_3163": ["CylindricalGearCompoundSteadyStateSynchronousResponse"],
        "_3164": ["CylindricalGearMeshCompoundSteadyStateSynchronousResponse"],
        "_3165": ["CylindricalGearSetCompoundSteadyStateSynchronousResponse"],
        "_3166": ["CylindricalPlanetGearCompoundSteadyStateSynchronousResponse"],
        "_3167": ["DatumCompoundSteadyStateSynchronousResponse"],
        "_3168": ["ExternalCADModelCompoundSteadyStateSynchronousResponse"],
        "_3169": ["FaceGearCompoundSteadyStateSynchronousResponse"],
        "_3170": ["FaceGearMeshCompoundSteadyStateSynchronousResponse"],
        "_3171": ["FaceGearSetCompoundSteadyStateSynchronousResponse"],
        "_3172": ["FEPartCompoundSteadyStateSynchronousResponse"],
        "_3173": ["FlexiblePinAssemblyCompoundSteadyStateSynchronousResponse"],
        "_3174": ["GearCompoundSteadyStateSynchronousResponse"],
        "_3175": ["GearMeshCompoundSteadyStateSynchronousResponse"],
        "_3176": ["GearSetCompoundSteadyStateSynchronousResponse"],
        "_3177": ["GuideDxfModelCompoundSteadyStateSynchronousResponse"],
        "_3178": ["HypoidGearCompoundSteadyStateSynchronousResponse"],
        "_3179": ["HypoidGearMeshCompoundSteadyStateSynchronousResponse"],
        "_3180": ["HypoidGearSetCompoundSteadyStateSynchronousResponse"],
        "_3181": [
            "InterMountableComponentConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_3182": [
            "KlingelnbergCycloPalloidConicalGearCompoundSteadyStateSynchronousResponse"
        ],
        "_3183": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_3184": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_3185": [
            "KlingelnbergCycloPalloidHypoidGearCompoundSteadyStateSynchronousResponse"
        ],
        "_3186": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_3187": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_3188": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundSteadyStateSynchronousResponse"
        ],
        "_3189": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_3190": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_3191": ["MassDiscCompoundSteadyStateSynchronousResponse"],
        "_3192": ["MeasurementComponentCompoundSteadyStateSynchronousResponse"],
        "_3193": ["MountableComponentCompoundSteadyStateSynchronousResponse"],
        "_3194": ["OilSealCompoundSteadyStateSynchronousResponse"],
        "_3195": ["PartCompoundSteadyStateSynchronousResponse"],
        "_3196": ["PartToPartShearCouplingCompoundSteadyStateSynchronousResponse"],
        "_3197": [
            "PartToPartShearCouplingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_3198": ["PartToPartShearCouplingHalfCompoundSteadyStateSynchronousResponse"],
        "_3199": ["PlanetaryConnectionCompoundSteadyStateSynchronousResponse"],
        "_3200": ["PlanetaryGearSetCompoundSteadyStateSynchronousResponse"],
        "_3201": ["PlanetCarrierCompoundSteadyStateSynchronousResponse"],
        "_3202": ["PointLoadCompoundSteadyStateSynchronousResponse"],
        "_3203": ["PowerLoadCompoundSteadyStateSynchronousResponse"],
        "_3204": ["PulleyCompoundSteadyStateSynchronousResponse"],
        "_3205": ["RingPinsCompoundSteadyStateSynchronousResponse"],
        "_3206": ["RingPinsToDiscConnectionCompoundSteadyStateSynchronousResponse"],
        "_3207": ["RollingRingAssemblyCompoundSteadyStateSynchronousResponse"],
        "_3208": ["RollingRingCompoundSteadyStateSynchronousResponse"],
        "_3209": ["RollingRingConnectionCompoundSteadyStateSynchronousResponse"],
        "_3210": ["RootAssemblyCompoundSteadyStateSynchronousResponse"],
        "_3211": ["ShaftCompoundSteadyStateSynchronousResponse"],
        "_3212": ["ShaftHubConnectionCompoundSteadyStateSynchronousResponse"],
        "_3213": [
            "ShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_3214": ["SpecialisedAssemblyCompoundSteadyStateSynchronousResponse"],
        "_3215": ["SpiralBevelGearCompoundSteadyStateSynchronousResponse"],
        "_3216": ["SpiralBevelGearMeshCompoundSteadyStateSynchronousResponse"],
        "_3217": ["SpiralBevelGearSetCompoundSteadyStateSynchronousResponse"],
        "_3218": ["SpringDamperCompoundSteadyStateSynchronousResponse"],
        "_3219": ["SpringDamperConnectionCompoundSteadyStateSynchronousResponse"],
        "_3220": ["SpringDamperHalfCompoundSteadyStateSynchronousResponse"],
        "_3221": ["StraightBevelDiffGearCompoundSteadyStateSynchronousResponse"],
        "_3222": ["StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponse"],
        "_3223": ["StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponse"],
        "_3224": ["StraightBevelGearCompoundSteadyStateSynchronousResponse"],
        "_3225": ["StraightBevelGearMeshCompoundSteadyStateSynchronousResponse"],
        "_3226": ["StraightBevelGearSetCompoundSteadyStateSynchronousResponse"],
        "_3227": ["StraightBevelPlanetGearCompoundSteadyStateSynchronousResponse"],
        "_3228": ["StraightBevelSunGearCompoundSteadyStateSynchronousResponse"],
        "_3229": ["SynchroniserCompoundSteadyStateSynchronousResponse"],
        "_3230": ["SynchroniserHalfCompoundSteadyStateSynchronousResponse"],
        "_3231": ["SynchroniserPartCompoundSteadyStateSynchronousResponse"],
        "_3232": ["SynchroniserSleeveCompoundSteadyStateSynchronousResponse"],
        "_3233": ["TorqueConverterCompoundSteadyStateSynchronousResponse"],
        "_3234": ["TorqueConverterConnectionCompoundSteadyStateSynchronousResponse"],
        "_3235": ["TorqueConverterPumpCompoundSteadyStateSynchronousResponse"],
        "_3236": ["TorqueConverterTurbineCompoundSteadyStateSynchronousResponse"],
        "_3237": ["UnbalancedMassCompoundSteadyStateSynchronousResponse"],
        "_3238": ["VirtualComponentCompoundSteadyStateSynchronousResponse"],
        "_3239": ["WormGearCompoundSteadyStateSynchronousResponse"],
        "_3240": ["WormGearMeshCompoundSteadyStateSynchronousResponse"],
        "_3241": ["WormGearSetCompoundSteadyStateSynchronousResponse"],
        "_3242": ["ZerolBevelGearCompoundSteadyStateSynchronousResponse"],
        "_3243": ["ZerolBevelGearMeshCompoundSteadyStateSynchronousResponse"],
        "_3244": ["ZerolBevelGearSetCompoundSteadyStateSynchronousResponse"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundSteadyStateSynchronousResponse",
    "AbstractShaftCompoundSteadyStateSynchronousResponse",
    "AbstractShaftOrHousingCompoundSteadyStateSynchronousResponse",
    "AbstractShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse",
    "AGMAGleasonConicalGearCompoundSteadyStateSynchronousResponse",
    "AGMAGleasonConicalGearMeshCompoundSteadyStateSynchronousResponse",
    "AGMAGleasonConicalGearSetCompoundSteadyStateSynchronousResponse",
    "AssemblyCompoundSteadyStateSynchronousResponse",
    "BearingCompoundSteadyStateSynchronousResponse",
    "BeltConnectionCompoundSteadyStateSynchronousResponse",
    "BeltDriveCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialGearCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialGearMeshCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialGearSetCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialPlanetGearCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialSunGearCompoundSteadyStateSynchronousResponse",
    "BevelGearCompoundSteadyStateSynchronousResponse",
    "BevelGearMeshCompoundSteadyStateSynchronousResponse",
    "BevelGearSetCompoundSteadyStateSynchronousResponse",
    "BoltCompoundSteadyStateSynchronousResponse",
    "BoltedJointCompoundSteadyStateSynchronousResponse",
    "ClutchCompoundSteadyStateSynchronousResponse",
    "ClutchConnectionCompoundSteadyStateSynchronousResponse",
    "ClutchHalfCompoundSteadyStateSynchronousResponse",
    "CoaxialConnectionCompoundSteadyStateSynchronousResponse",
    "ComponentCompoundSteadyStateSynchronousResponse",
    "ConceptCouplingCompoundSteadyStateSynchronousResponse",
    "ConceptCouplingConnectionCompoundSteadyStateSynchronousResponse",
    "ConceptCouplingHalfCompoundSteadyStateSynchronousResponse",
    "ConceptGearCompoundSteadyStateSynchronousResponse",
    "ConceptGearMeshCompoundSteadyStateSynchronousResponse",
    "ConceptGearSetCompoundSteadyStateSynchronousResponse",
    "ConicalGearCompoundSteadyStateSynchronousResponse",
    "ConicalGearMeshCompoundSteadyStateSynchronousResponse",
    "ConicalGearSetCompoundSteadyStateSynchronousResponse",
    "ConnectionCompoundSteadyStateSynchronousResponse",
    "ConnectorCompoundSteadyStateSynchronousResponse",
    "CouplingCompoundSteadyStateSynchronousResponse",
    "CouplingConnectionCompoundSteadyStateSynchronousResponse",
    "CouplingHalfCompoundSteadyStateSynchronousResponse",
    "CVTBeltConnectionCompoundSteadyStateSynchronousResponse",
    "CVTCompoundSteadyStateSynchronousResponse",
    "CVTPulleyCompoundSteadyStateSynchronousResponse",
    "CycloidalAssemblyCompoundSteadyStateSynchronousResponse",
    "CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse",
    "CycloidalDiscCompoundSteadyStateSynchronousResponse",
    "CycloidalDiscPlanetaryBearingConnectionCompoundSteadyStateSynchronousResponse",
    "CylindricalGearCompoundSteadyStateSynchronousResponse",
    "CylindricalGearMeshCompoundSteadyStateSynchronousResponse",
    "CylindricalGearSetCompoundSteadyStateSynchronousResponse",
    "CylindricalPlanetGearCompoundSteadyStateSynchronousResponse",
    "DatumCompoundSteadyStateSynchronousResponse",
    "ExternalCADModelCompoundSteadyStateSynchronousResponse",
    "FaceGearCompoundSteadyStateSynchronousResponse",
    "FaceGearMeshCompoundSteadyStateSynchronousResponse",
    "FaceGearSetCompoundSteadyStateSynchronousResponse",
    "FEPartCompoundSteadyStateSynchronousResponse",
    "FlexiblePinAssemblyCompoundSteadyStateSynchronousResponse",
    "GearCompoundSteadyStateSynchronousResponse",
    "GearMeshCompoundSteadyStateSynchronousResponse",
    "GearSetCompoundSteadyStateSynchronousResponse",
    "GuideDxfModelCompoundSteadyStateSynchronousResponse",
    "HypoidGearCompoundSteadyStateSynchronousResponse",
    "HypoidGearMeshCompoundSteadyStateSynchronousResponse",
    "HypoidGearSetCompoundSteadyStateSynchronousResponse",
    "InterMountableComponentConnectionCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidConicalGearCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidConicalGearSetCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidHypoidGearCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponse",
    "MassDiscCompoundSteadyStateSynchronousResponse",
    "MeasurementComponentCompoundSteadyStateSynchronousResponse",
    "MountableComponentCompoundSteadyStateSynchronousResponse",
    "OilSealCompoundSteadyStateSynchronousResponse",
    "PartCompoundSteadyStateSynchronousResponse",
    "PartToPartShearCouplingCompoundSteadyStateSynchronousResponse",
    "PartToPartShearCouplingConnectionCompoundSteadyStateSynchronousResponse",
    "PartToPartShearCouplingHalfCompoundSteadyStateSynchronousResponse",
    "PlanetaryConnectionCompoundSteadyStateSynchronousResponse",
    "PlanetaryGearSetCompoundSteadyStateSynchronousResponse",
    "PlanetCarrierCompoundSteadyStateSynchronousResponse",
    "PointLoadCompoundSteadyStateSynchronousResponse",
    "PowerLoadCompoundSteadyStateSynchronousResponse",
    "PulleyCompoundSteadyStateSynchronousResponse",
    "RingPinsCompoundSteadyStateSynchronousResponse",
    "RingPinsToDiscConnectionCompoundSteadyStateSynchronousResponse",
    "RollingRingAssemblyCompoundSteadyStateSynchronousResponse",
    "RollingRingCompoundSteadyStateSynchronousResponse",
    "RollingRingConnectionCompoundSteadyStateSynchronousResponse",
    "RootAssemblyCompoundSteadyStateSynchronousResponse",
    "ShaftCompoundSteadyStateSynchronousResponse",
    "ShaftHubConnectionCompoundSteadyStateSynchronousResponse",
    "ShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse",
    "SpecialisedAssemblyCompoundSteadyStateSynchronousResponse",
    "SpiralBevelGearCompoundSteadyStateSynchronousResponse",
    "SpiralBevelGearMeshCompoundSteadyStateSynchronousResponse",
    "SpiralBevelGearSetCompoundSteadyStateSynchronousResponse",
    "SpringDamperCompoundSteadyStateSynchronousResponse",
    "SpringDamperConnectionCompoundSteadyStateSynchronousResponse",
    "SpringDamperHalfCompoundSteadyStateSynchronousResponse",
    "StraightBevelDiffGearCompoundSteadyStateSynchronousResponse",
    "StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponse",
    "StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponse",
    "StraightBevelGearCompoundSteadyStateSynchronousResponse",
    "StraightBevelGearMeshCompoundSteadyStateSynchronousResponse",
    "StraightBevelGearSetCompoundSteadyStateSynchronousResponse",
    "StraightBevelPlanetGearCompoundSteadyStateSynchronousResponse",
    "StraightBevelSunGearCompoundSteadyStateSynchronousResponse",
    "SynchroniserCompoundSteadyStateSynchronousResponse",
    "SynchroniserHalfCompoundSteadyStateSynchronousResponse",
    "SynchroniserPartCompoundSteadyStateSynchronousResponse",
    "SynchroniserSleeveCompoundSteadyStateSynchronousResponse",
    "TorqueConverterCompoundSteadyStateSynchronousResponse",
    "TorqueConverterConnectionCompoundSteadyStateSynchronousResponse",
    "TorqueConverterPumpCompoundSteadyStateSynchronousResponse",
    "TorqueConverterTurbineCompoundSteadyStateSynchronousResponse",
    "UnbalancedMassCompoundSteadyStateSynchronousResponse",
    "VirtualComponentCompoundSteadyStateSynchronousResponse",
    "WormGearCompoundSteadyStateSynchronousResponse",
    "WormGearMeshCompoundSteadyStateSynchronousResponse",
    "WormGearSetCompoundSteadyStateSynchronousResponse",
    "ZerolBevelGearCompoundSteadyStateSynchronousResponse",
    "ZerolBevelGearMeshCompoundSteadyStateSynchronousResponse",
    "ZerolBevelGearSetCompoundSteadyStateSynchronousResponse",
)



"""HairpinConductor"""

from __future__ import annotations

from typing import TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy.electric_machines import _1311
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_HAIRPIN_CONDUCTOR = python_net_import(
    "SMT.MastaAPI.ElectricMachines", "HairpinConductor"
)


__docformat__ = "restructuredtext en"
__all__ = ("HairpinConductor",)


Self = TypeVar("Self", bound="HairpinConductor")


class HairpinConductor(_1311.WindingConductor):
    """HairpinConductor

    This is a mastapy class.
    """

    TYPE = _HAIRPIN_CONDUCTOR
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_HairpinConductor")

    class _Cast_HairpinConductor:
        """Special nested class for casting HairpinConductor to subclasses."""

        def __init__(
            self: "HairpinConductor._Cast_HairpinConductor", parent: "HairpinConductor"
        ):
            self._parent = parent

        @property
        def winding_conductor(
            self: "HairpinConductor._Cast_HairpinConductor",
        ) -> "_1311.WindingConductor":
            return self._parent._cast(_1311.WindingConductor)

        @property
        def hairpin_conductor(
            self: "HairpinConductor._Cast_HairpinConductor",
        ) -> "HairpinConductor":
            return self._parent

        def __getattr__(self: "HairpinConductor._Cast_HairpinConductor", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "HairpinConductor.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def angle(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Angle

        if temp is None:
            return 0.0

        return temp

    @angle.setter
    @enforce_parameter_types
    def angle(self: Self, value: "float"):
        self.wrapped.Angle = float(value) if value is not None else 0.0

    @property
    def angle_offset(self: Self) -> "float":
        """float"""
        temp = self.wrapped.AngleOffset

        if temp is None:
            return 0.0

        return temp

    @angle_offset.setter
    @enforce_parameter_types
    def angle_offset(self: Self, value: "float"):
        self.wrapped.AngleOffset = float(value) if value is not None else 0.0

    @property
    def corner_radius(self: Self) -> "float":
        """float"""
        temp = self.wrapped.CornerRadius

        if temp is None:
            return 0.0

        return temp

    @corner_radius.setter
    @enforce_parameter_types
    def corner_radius(self: Self, value: "float"):
        self.wrapped.CornerRadius = float(value) if value is not None else 0.0

    @property
    def radial_offset(self: Self) -> "float":
        """float"""
        temp = self.wrapped.RadialOffset

        if temp is None:
            return 0.0

        return temp

    @radial_offset.setter
    @enforce_parameter_types
    def radial_offset(self: Self, value: "float"):
        self.wrapped.RadialOffset = float(value) if value is not None else 0.0

    @property
    def radius(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Radius

        if temp is None:
            return 0.0

        return temp

    @radius.setter
    @enforce_parameter_types
    def radius(self: Self, value: "float"):
        self.wrapped.Radius = float(value) if value is not None else 0.0

    @property
    def winding_area(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WindingArea

        if temp is None:
            return 0.0

        return temp

    @property
    def winding_material_height(self: Self) -> "float":
        """float"""
        temp = self.wrapped.WindingMaterialHeight

        if temp is None:
            return 0.0

        return temp

    @winding_material_height.setter
    @enforce_parameter_types
    def winding_material_height(self: Self, value: "float"):
        self.wrapped.WindingMaterialHeight = float(value) if value is not None else 0.0

    @property
    def winding_material_width(self: Self) -> "float":
        """float"""
        temp = self.wrapped.WindingMaterialWidth

        if temp is None:
            return 0.0

        return temp

    @winding_material_width.setter
    @enforce_parameter_types
    def winding_material_width(self: Self, value: "float"):
        self.wrapped.WindingMaterialWidth = float(value) if value is not None else 0.0

    @property
    def cast_to(self: Self) -> "HairpinConductor._Cast_HairpinConductor":
        return self._Cast_HairpinConductor(self)



"""CylindricalMeshedGearSystemDeflection"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_MESHED_GEAR_SYSTEM_DEFLECTION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections",
    "CylindricalMeshedGearSystemDeflection",
)

if TYPE_CHECKING:
    from mastapy.system_model.analyses_and_results.system_deflections import (
        _2748,
        _2745,
        _2739,
    )
    from mastapy.gears.ltca import _845


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalMeshedGearSystemDeflection",)


Self = TypeVar("Self", bound="CylindricalMeshedGearSystemDeflection")


class CylindricalMeshedGearSystemDeflection(_0.APIBase):
    """CylindricalMeshedGearSystemDeflection

    This is a mastapy class.
    """

    TYPE = _CYLINDRICAL_MESHED_GEAR_SYSTEM_DEFLECTION
    _CastSelf = TypeVar(
        "_CastSelf", bound="_Cast_CylindricalMeshedGearSystemDeflection"
    )

    class _Cast_CylindricalMeshedGearSystemDeflection:
        """Special nested class for casting CylindricalMeshedGearSystemDeflection to subclasses."""

        def __init__(
            self: "CylindricalMeshedGearSystemDeflection._Cast_CylindricalMeshedGearSystemDeflection",
            parent: "CylindricalMeshedGearSystemDeflection",
        ):
            self._parent = parent

        @property
        def cylindrical_meshed_gear_system_deflection(
            self: "CylindricalMeshedGearSystemDeflection._Cast_CylindricalMeshedGearSystemDeflection",
        ) -> "CylindricalMeshedGearSystemDeflection":
            return self._parent

        def __getattr__(
            self: "CylindricalMeshedGearSystemDeflection._Cast_CylindricalMeshedGearSystemDeflection",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self, instance_to_wrap: "CylindricalMeshedGearSystemDeflection.TYPE"
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def change_in_operating_pitch_diameter_due_to_thermal_effects(
        self: Self,
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ChangeInOperatingPitchDiameterDueToThermalEffects

        if temp is None:
            return 0.0

        return temp

    @property
    def minimum_operating_tip_clearance(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MinimumOperatingTipClearance

        if temp is None:
            return 0.0

        return temp

    @property
    def operating_tip_diameter(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OperatingTipDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def tilt_x(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TiltX

        if temp is None:
            return 0.0

        return temp

    @property
    def tilt_y(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TiltY

        if temp is None:
            return 0.0

        return temp

    @property
    def left_flank(self: Self) -> "_2748.CylindricalMeshedGearFlankSystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.CylindricalMeshedGearFlankSystemDeflection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LeftFlank

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def right_flank(self: Self) -> "_2748.CylindricalMeshedGearFlankSystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.CylindricalMeshedGearFlankSystemDeflection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RightFlank

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def compression_side_fillet_results(
        self: Self,
    ) -> "List[_845.GearRootFilletStressResults]":
        """List[mastapy.gears.ltca.GearRootFilletStressResults]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CompressionSideFilletResults

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def flanks(self: Self) -> "List[_2748.CylindricalMeshedGearFlankSystemDeflection]":
        """List[mastapy.system_model.analyses_and_results.system_deflections.CylindricalMeshedGearFlankSystemDeflection]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Flanks

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def tension_side_fillet_results(
        self: Self,
    ) -> "List[_845.GearRootFilletStressResults]":
        """List[mastapy.gears.ltca.GearRootFilletStressResults]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TensionSideFilletResults

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def both_flanks(self: Self) -> "_2748.CylindricalMeshedGearFlankSystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.CylindricalMeshedGearFlankSystemDeflection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BothFlanks

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cylindrical_gear_system_deflection(
        self: Self,
    ) -> "_2745.CylindricalGearSystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.CylindricalGearSystemDeflection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CylindricalGearSystemDeflection

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cylindrical_gear_mesh_system_deflection(
        self: Self,
    ) -> "_2739.CylindricalGearMeshSystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.CylindricalGearMeshSystemDeflection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CylindricalGearMeshSystemDeflection

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def other_cylindrical_gear_system_deflection(
        self: Self,
    ) -> "_2745.CylindricalGearSystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.CylindricalGearSystemDeflection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OtherCylindricalGearSystemDeflection

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def report_names(self: Self) -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(self: Self, report_name: "str", file_path: "str"):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: Self, report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(
        self: Self,
    ) -> "CylindricalMeshedGearSystemDeflection._Cast_CylindricalMeshedGearSystemDeflection":
        return self._Cast_CylindricalMeshedGearSystemDeflection(self)



"""RoundnessSpecification"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion
from mastapy.utility import _1586
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ROUNDNESS_SPECIFICATION = python_net_import(
    "SMT.MastaAPI.Bearings.Tolerances", "RoundnessSpecification"
)

if TYPE_CHECKING:
    from mastapy.bearings.tolerances import _1919, _1925, _1915
    from mastapy.math_utility import _1534


__docformat__ = "restructuredtext en"
__all__ = ("RoundnessSpecification",)


Self = TypeVar("Self", bound="RoundnessSpecification")


class RoundnessSpecification(
    _1586.IndependentReportablePropertiesBase["RoundnessSpecification"]
):
    """RoundnessSpecification

    This is a mastapy class.
    """

    TYPE = _ROUNDNESS_SPECIFICATION
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_RoundnessSpecification")

    class _Cast_RoundnessSpecification:
        """Special nested class for casting RoundnessSpecification to subclasses."""

        def __init__(
            self: "RoundnessSpecification._Cast_RoundnessSpecification",
            parent: "RoundnessSpecification",
        ):
            self._parent = parent

        @property
        def independent_reportable_properties_base(
            self: "RoundnessSpecification._Cast_RoundnessSpecification",
        ) -> "_1586.IndependentReportablePropertiesBase":
            pass

            return self._parent._cast(_1586.IndependentReportablePropertiesBase)

        @property
        def roundness_specification(
            self: "RoundnessSpecification._Cast_RoundnessSpecification",
        ) -> "RoundnessSpecification":
            return self._parent

        def __getattr__(
            self: "RoundnessSpecification._Cast_RoundnessSpecification", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "RoundnessSpecification.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def angle_of_first_max_deviation_from_round(self: Self) -> "float":
        """float"""
        temp = self.wrapped.AngleOfFirstMaxDeviationFromRound

        if temp is None:
            return 0.0

        return temp

    @angle_of_first_max_deviation_from_round.setter
    @enforce_parameter_types
    def angle_of_first_max_deviation_from_round(self: Self, value: "float"):
        self.wrapped.AngleOfFirstMaxDeviationFromRound = (
            float(value) if value is not None else 0.0
        )

    @property
    def maximum_deviation_from_round(self: Self) -> "float":
        """float"""
        temp = self.wrapped.MaximumDeviationFromRound

        if temp is None:
            return 0.0

        return temp

    @maximum_deviation_from_round.setter
    @enforce_parameter_types
    def maximum_deviation_from_round(self: Self, value: "float"):
        self.wrapped.MaximumDeviationFromRound = (
            float(value) if value is not None else 0.0
        )

    @property
    def number_of_lobes(self: Self) -> "int":
        """int"""
        temp = self.wrapped.NumberOfLobes

        if temp is None:
            return 0

        return temp

    @number_of_lobes.setter
    @enforce_parameter_types
    def number_of_lobes(self: Self, value: "int"):
        self.wrapped.NumberOfLobes = int(value) if value is not None else 0

    @property
    def specification_type(self: Self) -> "_1919.RoundnessSpecificationType":
        """mastapy.bearings.tolerances.RoundnessSpecificationType"""
        temp = self.wrapped.SpecificationType

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Bearings.Tolerances.RoundnessSpecificationType"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.bearings.tolerances._1919", "RoundnessSpecificationType"
        )(value)

    @specification_type.setter
    @enforce_parameter_types
    def specification_type(self: Self, value: "_1919.RoundnessSpecificationType"):
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Bearings.Tolerances.RoundnessSpecificationType"
        )
        self.wrapped.SpecificationType = value

    @property
    def type_of_fit(self: Self) -> "_1925.TypeOfFit":
        """mastapy.bearings.tolerances.TypeOfFit"""
        temp = self.wrapped.TypeOfFit

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Bearings.Tolerances.TypeOfFit"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.bearings.tolerances._1925", "TypeOfFit"
        )(value)

    @type_of_fit.setter
    @enforce_parameter_types
    def type_of_fit(self: Self, value: "_1925.TypeOfFit"):
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Bearings.Tolerances.TypeOfFit"
        )
        self.wrapped.TypeOfFit = value

    @property
    def user_specified_deviation(self: Self) -> "_1534.Vector2DListAccessor":
        """mastapy.math_utility.Vector2DListAccessor"""
        temp = self.wrapped.UserSpecifiedDeviation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @user_specified_deviation.setter
    @enforce_parameter_types
    def user_specified_deviation(self: Self, value: "_1534.Vector2DListAccessor"):
        self.wrapped.UserSpecifiedDeviation = value.wrapped

    @property
    def roundness_distribution(self: Self) -> "List[_1915.RaceRoundnessAtAngle]":
        """List[mastapy.bearings.tolerances.RaceRoundnessAtAngle]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RoundnessDistribution

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: Self) -> "RoundnessSpecification._Cast_RoundnessSpecification":
        return self._Cast_RoundnessSpecification(self)



"""StraightBevelDiffGearRating"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.gears.rating.conical import _540
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_DIFF_GEAR_RATING = python_net_import(
    "SMT.MastaAPI.Gears.Rating.StraightBevelDiff", "StraightBevelDiffGearRating"
)

if TYPE_CHECKING:
    from mastapy.gears.gear_designs.straight_bevel_diff import _965
    from mastapy.gears.rating import _361, _354
    from mastapy.gears.analysis import _1215


__docformat__ = "restructuredtext en"
__all__ = ("StraightBevelDiffGearRating",)


Self = TypeVar("Self", bound="StraightBevelDiffGearRating")


class StraightBevelDiffGearRating(_540.ConicalGearRating):
    """StraightBevelDiffGearRating

    This is a mastapy class.
    """

    TYPE = _STRAIGHT_BEVEL_DIFF_GEAR_RATING
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_StraightBevelDiffGearRating")

    class _Cast_StraightBevelDiffGearRating:
        """Special nested class for casting StraightBevelDiffGearRating to subclasses."""

        def __init__(
            self: "StraightBevelDiffGearRating._Cast_StraightBevelDiffGearRating",
            parent: "StraightBevelDiffGearRating",
        ):
            self._parent = parent

        @property
        def conical_gear_rating(
            self: "StraightBevelDiffGearRating._Cast_StraightBevelDiffGearRating",
        ) -> "_540.ConicalGearRating":
            return self._parent._cast(_540.ConicalGearRating)

        @property
        def gear_rating(
            self: "StraightBevelDiffGearRating._Cast_StraightBevelDiffGearRating",
        ) -> "_361.GearRating":
            from mastapy.gears.rating import _361

            return self._parent._cast(_361.GearRating)

        @property
        def abstract_gear_rating(
            self: "StraightBevelDiffGearRating._Cast_StraightBevelDiffGearRating",
        ) -> "_354.AbstractGearRating":
            from mastapy.gears.rating import _354

            return self._parent._cast(_354.AbstractGearRating)

        @property
        def abstract_gear_analysis(
            self: "StraightBevelDiffGearRating._Cast_StraightBevelDiffGearRating",
        ) -> "_1215.AbstractGearAnalysis":
            from mastapy.gears.analysis import _1215

            return self._parent._cast(_1215.AbstractGearAnalysis)

        @property
        def straight_bevel_diff_gear_rating(
            self: "StraightBevelDiffGearRating._Cast_StraightBevelDiffGearRating",
        ) -> "StraightBevelDiffGearRating":
            return self._parent

        def __getattr__(
            self: "StraightBevelDiffGearRating._Cast_StraightBevelDiffGearRating",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "StraightBevelDiffGearRating.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cycles_to_fail(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CyclesToFail

        if temp is None:
            return 0.0

        return temp

    @property
    def cycles_to_fail_bending(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CyclesToFailBending

        if temp is None:
            return 0.0

        return temp

    @property
    def cycles_to_fail_contact(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CyclesToFailContact

        if temp is None:
            return 0.0

        return temp

    @property
    def time_to_fail(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TimeToFail

        if temp is None:
            return 0.0

        return temp

    @property
    def time_to_fail_bending(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TimeToFailBending

        if temp is None:
            return 0.0

        return temp

    @property
    def time_to_fail_contact(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TimeToFailContact

        if temp is None:
            return 0.0

        return temp

    @property
    def straight_bevel_diff_gear(self: Self) -> "_965.StraightBevelDiffGearDesign":
        """mastapy.gears.gear_designs.straight_bevel_diff.StraightBevelDiffGearDesign

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StraightBevelDiffGear

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "StraightBevelDiffGearRating._Cast_StraightBevelDiffGearRating":
        return self._Cast_StraightBevelDiffGearRating(self)



"""BoltSection"""

from __future__ import annotations

from typing import TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_BOLT_SECTION = python_net_import("SMT.MastaAPI.Bolts", "BoltSection")


__docformat__ = "restructuredtext en"
__all__ = ("BoltSection",)


Self = TypeVar("Self", bound="BoltSection")


class BoltSection(_0.APIBase):
    """BoltSection

    This is a mastapy class.
    """

    TYPE = _BOLT_SECTION
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_BoltSection")

    class _Cast_BoltSection:
        """Special nested class for casting BoltSection to subclasses."""

        def __init__(self: "BoltSection._Cast_BoltSection", parent: "BoltSection"):
            self._parent = parent

        @property
        def bolt_section(self: "BoltSection._Cast_BoltSection") -> "BoltSection":
            return self._parent

        def __getattr__(self: "BoltSection._Cast_BoltSection", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "BoltSection.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def diameter(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Diameter

        if temp is None:
            return 0.0

        return temp

    @diameter.setter
    @enforce_parameter_types
    def diameter(self: Self, value: "float"):
        self.wrapped.Diameter = float(value) if value is not None else 0.0

    @property
    def inner_diameter(self: Self) -> "float":
        """float"""
        temp = self.wrapped.InnerDiameter

        if temp is None:
            return 0.0

        return temp

    @inner_diameter.setter
    @enforce_parameter_types
    def inner_diameter(self: Self, value: "float"):
        self.wrapped.InnerDiameter = float(value) if value is not None else 0.0

    @property
    def length(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Length

        if temp is None:
            return 0.0

        return temp

    @length.setter
    @enforce_parameter_types
    def length(self: Self, value: "float"):
        self.wrapped.Length = float(value) if value is not None else 0.0

    @property
    def cast_to(self: Self) -> "BoltSection._Cast_BoltSection":
        return self._Cast_BoltSection(self)



"""Micropitting"""

from __future__ import annotations

from typing import TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import enum_with_selected_value_runtime, conversion
from mastapy._internal.implicit import enum_with_selected_value
from mastapy.gears import _338
from mastapy.utility import _1586
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_MICROPITTING = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical", "Micropitting"
)


__docformat__ = "restructuredtext en"
__all__ = ("Micropitting",)


Self = TypeVar("Self", bound="Micropitting")


class Micropitting(_1586.IndependentReportablePropertiesBase["Micropitting"]):
    """Micropitting

    This is a mastapy class.
    """

    TYPE = _MICROPITTING
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_Micropitting")

    class _Cast_Micropitting:
        """Special nested class for casting Micropitting to subclasses."""

        def __init__(self: "Micropitting._Cast_Micropitting", parent: "Micropitting"):
            self._parent = parent

        @property
        def independent_reportable_properties_base(
            self: "Micropitting._Cast_Micropitting",
        ) -> "_1586.IndependentReportablePropertiesBase":
            pass

            return self._parent._cast(_1586.IndependentReportablePropertiesBase)

        @property
        def micropitting(self: "Micropitting._Cast_Micropitting") -> "Micropitting":
            return self._parent

        def __getattr__(self: "Micropitting._Cast_Micropitting", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "Micropitting.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def estimate_bulk_temperature(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.EstimateBulkTemperature

        if temp is None:
            return False

        return temp

    @estimate_bulk_temperature.setter
    @enforce_parameter_types
    def estimate_bulk_temperature(self: Self, value: "bool"):
        self.wrapped.EstimateBulkTemperature = (
            bool(value) if value is not None else False
        )

    @property
    def method_a_coefficient_of_friction_method(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_MicropittingCoefficientOfFrictionCalculationMethod":
        """EnumWithSelectedValue[mastapy.gears.MicropittingCoefficientOfFrictionCalculationMethod]"""
        temp = self.wrapped.MethodACoefficientOfFrictionMethod

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_MicropittingCoefficientOfFrictionCalculationMethod.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @method_a_coefficient_of_friction_method.setter
    @enforce_parameter_types
    def method_a_coefficient_of_friction_method(
        self: Self, value: "_338.MicropittingCoefficientOfFrictionCalculationMethod"
    ):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_MicropittingCoefficientOfFrictionCalculationMethod.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.MethodACoefficientOfFrictionMethod = value

    @property
    def cast_to(self: Self) -> "Micropitting._Cast_Micropitting":
        return self._Cast_Micropitting(self)



"""DIN5480SplineHalfDesign"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion
from mastapy.detailed_rigid_connectors.splines import _1418
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_DIN5480_SPLINE_HALF_DESIGN = python_net_import(
    "SMT.MastaAPI.DetailedRigidConnectors.Splines", "DIN5480SplineHalfDesign"
)

if TYPE_CHECKING:
    from mastapy.detailed_rigid_connectors.splines import _1410, _1401, _1413
    from mastapy.detailed_rigid_connectors import _1387


__docformat__ = "restructuredtext en"
__all__ = ("DIN5480SplineHalfDesign",)


Self = TypeVar("Self", bound="DIN5480SplineHalfDesign")


class DIN5480SplineHalfDesign(_1418.StandardSplineHalfDesign):
    """DIN5480SplineHalfDesign

    This is a mastapy class.
    """

    TYPE = _DIN5480_SPLINE_HALF_DESIGN
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_DIN5480SplineHalfDesign")

    class _Cast_DIN5480SplineHalfDesign:
        """Special nested class for casting DIN5480SplineHalfDesign to subclasses."""

        def __init__(
            self: "DIN5480SplineHalfDesign._Cast_DIN5480SplineHalfDesign",
            parent: "DIN5480SplineHalfDesign",
        ):
            self._parent = parent

        @property
        def standard_spline_half_design(
            self: "DIN5480SplineHalfDesign._Cast_DIN5480SplineHalfDesign",
        ) -> "_1418.StandardSplineHalfDesign":
            return self._parent._cast(_1418.StandardSplineHalfDesign)

        @property
        def spline_half_design(
            self: "DIN5480SplineHalfDesign._Cast_DIN5480SplineHalfDesign",
        ) -> "_1413.SplineHalfDesign":
            from mastapy.detailed_rigid_connectors.splines import _1413

            return self._parent._cast(_1413.SplineHalfDesign)

        @property
        def detailed_rigid_connector_half_design(
            self: "DIN5480SplineHalfDesign._Cast_DIN5480SplineHalfDesign",
        ) -> "_1387.DetailedRigidConnectorHalfDesign":
            from mastapy.detailed_rigid_connectors import _1387

            return self._parent._cast(_1387.DetailedRigidConnectorHalfDesign)

        @property
        def din5480_spline_half_design(
            self: "DIN5480SplineHalfDesign._Cast_DIN5480SplineHalfDesign",
        ) -> "DIN5480SplineHalfDesign":
            return self._parent

        def __getattr__(
            self: "DIN5480SplineHalfDesign._Cast_DIN5480SplineHalfDesign", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "DIN5480SplineHalfDesign.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def addendum_modification(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AddendumModification

        if temp is None:
            return 0.0

        return temp

    @property
    def addendum_of_basic_rack(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AddendumOfBasicRack

        if temp is None:
            return 0.0

        return temp

    @property
    def base_form_circle_diameter_limit(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BaseFormCircleDiameterLimit

        if temp is None:
            return 0.0

        return temp

    @property
    def basic_rack_addendum_factor(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BasicRackAddendumFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def basic_rack_dedendum_factor(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BasicRackDedendumFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def bottom_clearance_of_basic_rack(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BottomClearanceOfBasicRack

        if temp is None:
            return 0.0

        return temp

    @property
    def dedendum_of_basic_rack(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DedendumOfBasicRack

        if temp is None:
            return 0.0

        return temp

    @property
    def finishing_method(self: Self) -> "_1410.FinishingMethods":
        """mastapy.detailed_rigid_connectors.splines.FinishingMethods"""
        temp = self.wrapped.FinishingMethod

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.DetailedRigidConnectors.Splines.FinishingMethods"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.detailed_rigid_connectors.splines._1410", "FinishingMethods"
        )(value)

    @finishing_method.setter
    @enforce_parameter_types
    def finishing_method(self: Self, value: "_1410.FinishingMethods"):
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.DetailedRigidConnectors.Splines.FinishingMethods"
        )
        self.wrapped.FinishingMethod = value

    @property
    def form_clearance_of_basic_rack(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FormClearanceOfBasicRack

        if temp is None:
            return 0.0

        return temp

    @property
    def manufacturing_type(self: Self) -> "_1401.ManufacturingTypes":
        """mastapy.detailed_rigid_connectors.splines.ManufacturingTypes"""
        temp = self.wrapped.ManufacturingType

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.DetailedRigidConnectors.Splines.ManufacturingTypes"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.detailed_rigid_connectors.splines._1401", "ManufacturingTypes"
        )(value)

    @manufacturing_type.setter
    @enforce_parameter_types
    def manufacturing_type(self: Self, value: "_1401.ManufacturingTypes"):
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.DetailedRigidConnectors.Splines.ManufacturingTypes"
        )
        self.wrapped.ManufacturingType = value

    @property
    def maximum_actual_space_width(self: Self) -> "float":
        """float"""
        temp = self.wrapped.MaximumActualSpaceWidth

        if temp is None:
            return 0.0

        return temp

    @maximum_actual_space_width.setter
    @enforce_parameter_types
    def maximum_actual_space_width(self: Self, value: "float"):
        self.wrapped.MaximumActualSpaceWidth = (
            float(value) if value is not None else 0.0
        )

    @property
    def maximum_actual_tooth_thickness(self: Self) -> "float":
        """float"""
        temp = self.wrapped.MaximumActualToothThickness

        if temp is None:
            return 0.0

        return temp

    @maximum_actual_tooth_thickness.setter
    @enforce_parameter_types
    def maximum_actual_tooth_thickness(self: Self, value: "float"):
        self.wrapped.MaximumActualToothThickness = (
            float(value) if value is not None else 0.0
        )

    @property
    def maximum_effective_root_diameter(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumEffectiveRootDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_effective_tooth_thickness(self: Self) -> "float":
        """float"""
        temp = self.wrapped.MaximumEffectiveToothThickness

        if temp is None:
            return 0.0

        return temp

    @maximum_effective_tooth_thickness.setter
    @enforce_parameter_types
    def maximum_effective_tooth_thickness(self: Self, value: "float"):
        self.wrapped.MaximumEffectiveToothThickness = (
            float(value) if value is not None else 0.0
        )

    @property
    def minimum_actual_space_width(self: Self) -> "float":
        """float"""
        temp = self.wrapped.MinimumActualSpaceWidth

        if temp is None:
            return 0.0

        return temp

    @minimum_actual_space_width.setter
    @enforce_parameter_types
    def minimum_actual_space_width(self: Self, value: "float"):
        self.wrapped.MinimumActualSpaceWidth = (
            float(value) if value is not None else 0.0
        )

    @property
    def minimum_actual_tooth_thickness(self: Self) -> "float":
        """float"""
        temp = self.wrapped.MinimumActualToothThickness

        if temp is None:
            return 0.0

        return temp

    @minimum_actual_tooth_thickness.setter
    @enforce_parameter_types
    def minimum_actual_tooth_thickness(self: Self, value: "float"):
        self.wrapped.MinimumActualToothThickness = (
            float(value) if value is not None else 0.0
        )

    @property
    def minimum_effective_root_diameter(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MinimumEffectiveRootDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def minimum_effective_space_width(self: Self) -> "float":
        """float"""
        temp = self.wrapped.MinimumEffectiveSpaceWidth

        if temp is None:
            return 0.0

        return temp

    @minimum_effective_space_width.setter
    @enforce_parameter_types
    def minimum_effective_space_width(self: Self, value: "float"):
        self.wrapped.MinimumEffectiveSpaceWidth = (
            float(value) if value is not None else 0.0
        )

    @property
    def root_diameter(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RootDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def root_fillet_radius_factor(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RootFilletRadiusFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def tip_diameter(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TipDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def tooth_height_of_basic_rack(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ToothHeightOfBasicRack

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: Self) -> "DIN5480SplineHalfDesign._Cast_DIN5480SplineHalfDesign":
        return self._Cast_DIN5480SplineHalfDesign(self)



"""BevelGearMeshRating"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal.implicit import overridable
from mastapy._internal import constructor, conversion
from mastapy.gears.rating.agma_gleason_conical import _565
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_BEVEL_GEAR_MESH_RATING = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Bevel", "BevelGearMeshRating"
)

if TYPE_CHECKING:
    from mastapy.gears.rating.bevel.standards import _558, _560
    from mastapy.gears.rating.iso_10300 import _425, _423
    from mastapy.gears.rating.conical import _545, _539
    from mastapy.gears.rating.zerol_bevel import _369
    from mastapy.gears.rating.straight_bevel import _395
    from mastapy.gears.rating.spiral_bevel import _402
    from mastapy.gears.rating import _360, _353
    from mastapy.gears.analysis import _1216


__docformat__ = "restructuredtext en"
__all__ = ("BevelGearMeshRating",)


Self = TypeVar("Self", bound="BevelGearMeshRating")


class BevelGearMeshRating(_565.AGMAGleasonConicalGearMeshRating):
    """BevelGearMeshRating

    This is a mastapy class.
    """

    TYPE = _BEVEL_GEAR_MESH_RATING
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_BevelGearMeshRating")

    class _Cast_BevelGearMeshRating:
        """Special nested class for casting BevelGearMeshRating to subclasses."""

        def __init__(
            self: "BevelGearMeshRating._Cast_BevelGearMeshRating",
            parent: "BevelGearMeshRating",
        ):
            self._parent = parent

        @property
        def agma_gleason_conical_gear_mesh_rating(
            self: "BevelGearMeshRating._Cast_BevelGearMeshRating",
        ) -> "_565.AGMAGleasonConicalGearMeshRating":
            return self._parent._cast(_565.AGMAGleasonConicalGearMeshRating)

        @property
        def conical_gear_mesh_rating(
            self: "BevelGearMeshRating._Cast_BevelGearMeshRating",
        ) -> "_539.ConicalGearMeshRating":
            from mastapy.gears.rating.conical import _539

            return self._parent._cast(_539.ConicalGearMeshRating)

        @property
        def gear_mesh_rating(
            self: "BevelGearMeshRating._Cast_BevelGearMeshRating",
        ) -> "_360.GearMeshRating":
            from mastapy.gears.rating import _360

            return self._parent._cast(_360.GearMeshRating)

        @property
        def abstract_gear_mesh_rating(
            self: "BevelGearMeshRating._Cast_BevelGearMeshRating",
        ) -> "_353.AbstractGearMeshRating":
            from mastapy.gears.rating import _353

            return self._parent._cast(_353.AbstractGearMeshRating)

        @property
        def abstract_gear_mesh_analysis(
            self: "BevelGearMeshRating._Cast_BevelGearMeshRating",
        ) -> "_1216.AbstractGearMeshAnalysis":
            from mastapy.gears.analysis import _1216

            return self._parent._cast(_1216.AbstractGearMeshAnalysis)

        @property
        def zerol_bevel_gear_mesh_rating(
            self: "BevelGearMeshRating._Cast_BevelGearMeshRating",
        ) -> "_369.ZerolBevelGearMeshRating":
            from mastapy.gears.rating.zerol_bevel import _369

            return self._parent._cast(_369.ZerolBevelGearMeshRating)

        @property
        def straight_bevel_gear_mesh_rating(
            self: "BevelGearMeshRating._Cast_BevelGearMeshRating",
        ) -> "_395.StraightBevelGearMeshRating":
            from mastapy.gears.rating.straight_bevel import _395

            return self._parent._cast(_395.StraightBevelGearMeshRating)

        @property
        def spiral_bevel_gear_mesh_rating(
            self: "BevelGearMeshRating._Cast_BevelGearMeshRating",
        ) -> "_402.SpiralBevelGearMeshRating":
            from mastapy.gears.rating.spiral_bevel import _402

            return self._parent._cast(_402.SpiralBevelGearMeshRating)

        @property
        def bevel_gear_mesh_rating(
            self: "BevelGearMeshRating._Cast_BevelGearMeshRating",
        ) -> "BevelGearMeshRating":
            return self._parent

        def __getattr__(
            self: "BevelGearMeshRating._Cast_BevelGearMeshRating", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "BevelGearMeshRating.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def size_factor_bending(self: Self) -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SizeFactorBending

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    def size_factor_contact(self: Self) -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SizeFactorContact

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    def agma_bevel_mesh_single_flank_rating(
        self: Self,
    ) -> "_558.AGMASpiralBevelMeshSingleFlankRating":
        """mastapy.gears.rating.bevel.standards.AGMASpiralBevelMeshSingleFlankRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AGMABevelMeshSingleFlankRating

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def gleason_bevel_mesh_single_flank_rating(
        self: Self,
    ) -> "_560.GleasonSpiralBevelMeshSingleFlankRating":
        """mastapy.gears.rating.bevel.standards.GleasonSpiralBevelMeshSingleFlankRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GleasonBevelMeshSingleFlankRating

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def iso10300_bevel_mesh_single_flank_rating_method_b1(
        self: Self,
    ) -> "_425.ISO10300MeshSingleFlankRatingMethodB1":
        """mastapy.gears.rating.isoISO10300MeshSingleFlankRatingMethodB1

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ISO10300BevelMeshSingleFlankRatingMethodB1

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def iso10300_bevel_mesh_single_flank_rating_method_b2(
        self: Self,
    ) -> "_423.ISO10300MeshSingleFlankRatingBevelMethodB2":
        """mastapy.gears.rating.isoISO10300MeshSingleFlankRatingBevelMethodB2

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ISO10300BevelMeshSingleFlankRatingMethodB2

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def meshed_gears(self: Self) -> "List[_545.ConicalMeshedGearRating]":
        """List[mastapy.gears.rating.conical.ConicalMeshedGearRating]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeshedGears

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def gears_in_mesh(self: Self) -> "List[_545.ConicalMeshedGearRating]":
        """List[mastapy.gears.rating.conical.ConicalMeshedGearRating]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearsInMesh

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: Self) -> "BevelGearMeshRating._Cast_BevelGearMeshRating":
        return self._Cast_BevelGearMeshRating(self)



"""GearFilletNodeStressResultsRow"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import conversion
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_GEAR_FILLET_NODE_STRESS_RESULTS_ROW = python_net_import(
    "SMT.MastaAPI.Gears.LTCA", "GearFilletNodeStressResultsRow"
)

if TYPE_CHECKING:
    from mastapy.gears.ltca import _837, _830


__docformat__ = "restructuredtext en"
__all__ = ("GearFilletNodeStressResultsRow",)


Self = TypeVar("Self", bound="GearFilletNodeStressResultsRow")


class GearFilletNodeStressResultsRow(_0.APIBase):
    """GearFilletNodeStressResultsRow

    This is a mastapy class.
    """

    TYPE = _GEAR_FILLET_NODE_STRESS_RESULTS_ROW
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_GearFilletNodeStressResultsRow")

    class _Cast_GearFilletNodeStressResultsRow:
        """Special nested class for casting GearFilletNodeStressResultsRow to subclasses."""

        def __init__(
            self: "GearFilletNodeStressResultsRow._Cast_GearFilletNodeStressResultsRow",
            parent: "GearFilletNodeStressResultsRow",
        ):
            self._parent = parent

        @property
        def cylindrical_gear_fillet_node_stress_results_row(
            self: "GearFilletNodeStressResultsRow._Cast_GearFilletNodeStressResultsRow",
        ) -> "_830.CylindricalGearFilletNodeStressResultsRow":
            from mastapy.gears.ltca import _830

            return self._parent._cast(_830.CylindricalGearFilletNodeStressResultsRow)

        @property
        def gear_fillet_node_stress_results_row(
            self: "GearFilletNodeStressResultsRow._Cast_GearFilletNodeStressResultsRow",
        ) -> "GearFilletNodeStressResultsRow":
            return self._parent

        def __getattr__(
            self: "GearFilletNodeStressResultsRow._Cast_GearFilletNodeStressResultsRow",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "GearFilletNodeStressResultsRow.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def fillet_row_index(self: Self) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FilletRowIndex

        if temp is None:
            return 0

        return temp

    @property
    def node_results(self: Self) -> "List[_837.GearFilletNodeStressResults]":
        """List[mastapy.gears.ltca.GearFilletNodeStressResults]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NodeResults

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: Self,
    ) -> "GearFilletNodeStressResultsRow._Cast_GearFilletNodeStressResultsRow":
        return self._Cast_GearFilletNodeStressResultsRow(self)
